Helper types to work with taps, inspired by Axum’s magic functions.
Although the module is called “tap”, it is used in multiple places in wsdf, beyond the tap
attribute.
See https://github.com/alexpusch/rust-magic-function-params for how the magic parameter passing stuff works.
Structs
- Field
- The current field, if any. The absence of a value is represented by
Field(()). - Fields
- A key value store of previous fields encountered and saved. Each key is the Wireshark filter for that field.
- Offset
- Current offset into the packet.
- Packet
- Raw bytes of the packet.
- Packet
Nanos - The nanosecond timestamp recorded in the packet capture data.